@@ -28,7 +28,6 @@ use std::sync::Arc;
 use std::thread::{self, JoinHandle};
 use std::time::{Duration, SystemTime, UNIX_EPOCH};
 use std::vec::Vec;
-use std::{u32, u64};
 
 use crate::dirent;
 use crate::dotcntr::DotcntrDir;
@@ -149,7 +148,7 @@ pub enum LookupFile<'a> {
     Borrow(&'a File),
 }
 
-impl<'a> AsRawFd for LookupFile<'a> {
+impl AsRawFd for LookupFile<'_> {
     fn as_raw_fd(&self) -> RawFd {
         match *self {
             LookupFile::Donate(ref f) => f.as_raw_fd(),
@@ -158,7 +157,7 @@ impl<'a> AsRawFd for LookupFile<'a> {
     }
 }
 
-impl<'a> LookupFile<'a> {
+impl LookupFile<'_> {
     fn into_raw_fd(self) -> nix::Result<RawFd> {
         match self {
             LookupFile::Donate(f) => Ok(f.into_raw_fd()),
@@ -246,7 +245,7 @@ impl CntrFs {
 
         let create_mode = stat::Mode::from_bits_truncate(mode);
         let fd = fcntl::openat(
-            parent_fd.raw(),
+            Some(parent_fd.raw()),
             name,
             oflag | OFlag::O_NOFOLLOW | OFlag::O_CLOEXEC,
             create_mode,
@@ -258,7 +257,7 @@ impl CntrFs {
         let mut sessions = Vec::new();
 
         // numbers of sessions is optimized for cached read
-        let num_sessions = cmp::max(num_cpus::get() / 2, 1) as usize;
+        let num_sessions = cmp::max(num_cpus::get() / 2, 1);
 
         for _ in 0..num_sessions {
             debug!("spawn worker");
@@ -346,7 +345,7 @@ impl CntrFs {
         }
 
         if let Some(s) = size {
-            unistd::ftruncate(fd.raw(), s as off_t)?;
+            unistd::ftruncate(fd.as_fd(), s as off_t)?;
         }
         if mtime != cntr_fuse::UtimeSpec::Omit || atime != cntr_fuse::UtimeSpec::Omit {
             let inode = self.inode(ino)?;
@@ -380,7 +379,7 @@ impl CntrFs {
                     match reply {
                         ReplyDirectory::Directory(ref mut r) => r.add(
                             entry.d_ino,
-                            dirp.offset as i64,
+                            dirp.offset,
                             dtype_kind(entry.d_type),
                             OsStr::from_bytes(name.to_bytes()),
                         ),
@@ -388,7 +387,7 @@ impl CntrFs {
                             match self.lookup_inode(ino, OsStr::from_bytes(name.to_bytes())) {
                                 Ok((attr, generation)) => r.add(
                                     entry.d_ino,
-                                    dirp.offset as i64,
+                                    dirp.offset,
                                     OsStr::from_bytes(name.to_bytes()),
                                     &TTL,
                                     &attr,
@@ -416,7 +415,7 @@ impl CntrFs {
     fn attr_from_stat(&self, attr: stat::FileStat) -> FileAttr {
         let ctime = UNIX_EPOCH + Duration::new(attr.st_ctime as u64, attr.st_ctime_nsec as u32);
         FileAttr {
-            ino: attr.st_ino as u64, // replaced by ino pointer
+            ino: attr.st_ino, // replaced by ino pointer
             size: attr.st_size as u64,
             blocks: attr.st_blocks as u64,
             atime: UNIX_EPOCH + Duration::new(attr.st_atime as u64, attr.st_atime_nsec as u32),
@@ -427,6 +426,7 @@ impl CntrFs {
             gid: self.gid_map.map_id_down(attr.st_gid),
             perm: attr.st_mode as u16,
             kind: inode_kind(stat::SFlag::from_bits_truncate(attr.st_mode)),
+            #[allow(clippy::unnecessary_cast)]
             nlink: attr.st_nlink as u32,
             rdev: attr.st_rdev as u32,
             // Flags (OS X only, see chflags(2))
@@ -528,7 +528,7 @@ impl CntrFs {
         let parent_inode = self.inode(parent)?;
         let parent_fd = parent_inode.fd.read();
         let fd = fcntl::openat(
-            parent_fd.raw(),
+            Some(parent_fd.as_fd().as_raw_fd()),
             name,
             OFlag::O_PATH | OFlag::O_NOFOLLOW | OFlag::O_CLOEXEC,
             stat::Mode::empty(),
@@ -768,7 +768,10 @@ impl Filesystem for CntrFs {
 
             let perm = stat::Mode::from_bits_truncate(mode);
             let fd = inode.fd.read();
-            tryfuse!(stat::mkdirat(fd.raw(), name, perm), reply);
+            tryfuse!(
+                stat::mkdirat(Some(fd.as_fd().as_raw_fd()), name, perm),
+                reply
+            );
         }
         self.lookup(req, parent, name, reply);
     }
@@ -933,7 +936,7 @@ impl Filesystem for CntrFs {
         let mut v = vec![0; size as usize];
         let buf = v.as_mut_slice();
         tryfuse!(
-            pread(get_filehandle(fh).fd.raw(), buf, offset as off_t),
+            pread(get_filehandle(fh).fd.as_fd(), buf, offset as off_t),
             reply
         );
 
@@ -951,7 +954,7 @@ impl Filesystem for CntrFs {
         reply: ReplyWrite,
     ) {
         fsuid::set_root();
-        let dst_fd = get_filehandle(fh).fd.raw();
+        let dst_fd = get_filehandle(fh).fd.as_fd();
 
         let written = tryfuse!(pwrite(dst_fd, data, offset as off_t), reply);
 
@@ -1348,7 +1351,9 @@ impl Filesystem for CntrFs {
 
         let fd = get_filehandle(fh).fd.raw();
         let new_offset = tryfuse!(
-            unistd::lseek64(fd, offset, unsafe { mem::transmute(whence as i32) }),
+            unistd::lseek64(fd, offset, unsafe {
+                mem::transmute::<i32, nix::unistd::Whence>(whence as i32)
+            }),
             reply
         );
         reply.offset(new_offset);
